@@ -50,7 +50,7 @@
 #include "text.h"
 #include "zoom.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "citydlg.h" /* For reset_city_dialogs() */
 #include "editgui.h"
 #include "graphics.h"
@@ -81,31 +81,15 @@ void update_turn_done_button(bool do_restore)
   }
 
   if ((do_restore && flip) || !do_restore) {
-    static GtkCssProvider *tdb_provider = NULL;
-    GtkStyleContext *scontext = gtk_widget_get_style_context(turn_done_button);
+    GdkRGBA fore;
+    GdkRGBA back;
+    GtkStyleContext *context = gtk_widget_get_style_context(turn_done_button);
 
-    if (tdb_provider == NULL) {
-      tdb_provider = gtk_css_provider_new();
+    gtk_style_context_get_color(context, GTK_STATE_FLAG_NORMAL, &fore);
+    gtk_style_context_get_background_color(context, GTK_STATE_FLAG_NORMAL, &back);
 
-      gtk_css_provider_load_from_data(tdb_provider,
-                                      ".lighted {\n"
-                                      "color: rgba(235, 127, 235, 255);\n"
-                                      "background-color: rgba(127, 127, 127, 255);\n"
-                                      "}\n",
-                                      -1, NULL);
-
-      /* Turn Done button is persistent, so we only need to do this
-       * once too. */
-      gtk_style_context_add_provider(scontext,
-                                     GTK_STYLE_PROVIDER(tdb_provider),
-                                     GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-    }
-
-    if (flip) {
-      gtk_style_context_add_class(scontext, "lighted");
-    } else {
-      gtk_style_context_remove_class(scontext, "lighted");
-    }
+    gtk_widget_override_color(turn_done_button, GTK_STATE_FLAG_NORMAL, &back);
+    gtk_widget_override_background_color(turn_done_button, GTK_STATE_FLAG_NORMAL, &fore);
 
     flip = !flip;
   }
@@ -168,7 +152,7 @@ void update_info_label(void)
   }
 
   gtk_label_set_text(GTK_LABEL(main_label_info),
-                     get_info_label_text(!GUI_GTK_OPTION(small_display_layout)));
+                     get_info_label_text(!gui_options.gui_gtk3_small_display_layout));
 
   set_indicator_icons(client_research_sprite(),
                       client_warming_sprite(),
@@ -502,23 +486,16 @@ void update_city_descriptions(void)
 /**************************************************************************
   Fill image with unit gfx
 **************************************************************************/
-void put_unit_image(struct unit *punit, GtkImage *p, int height)
+void put_unit_image(struct unit *punit, GtkImage *p)
 {
-  struct canvas store = FC_STATIC_CANVAS_INIT;
-  int width;
+  GdkPixbuf *pixbuf;
+  struct sprite *spr;
 
-  if (height <= 0) {
-    height = tileset_full_tile_height(tileset);
-  }
-  width = tileset_full_tile_width(tileset);
+  spr = get_unittype_sprite(tileset, unit_type_get(punit), punit->facing, FALSE);
+  pixbuf = sprite_get_pixbuf(spr);
 
-  store.surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
-                                             width, height);
-
-  put_unit(punit, &store, 1.0, 0, 0);
-
-  gtk_image_set_from_surface(p, store.surface);
-  cairo_surface_destroy(store.surface);
+  gtk_image_set_from_pixbuf(p, pixbuf);
+  g_object_unref(pixbuf);
 }
 
 /**************************************************************************
@@ -553,23 +530,20 @@ void put_unit_image_city_overlays(struct unit *punit, GtkImage *p,
   Put overlay tile to pixmap
 **************************************************************************/
 void pixmap_put_overlay_tile(GdkWindow *pixmap, float zoom,
-                             int canvas_x, int canvas_y,
-                             struct sprite *ssprite)
+			     int canvas_x, int canvas_y,
+			     struct sprite *ssprite)
 {
   cairo_t *cr;
-  GdkDrawingContext *ctx;
 
   if (!ssprite) {
     return;
   }
 
-  ctx = gdk_window_begin_draw_frame(pixmap,
-                                    gdk_window_get_clip_region(pixmap));
-  cr = gdk_drawing_context_get_cairo_context(ctx);
+  cr = gdk_cairo_create(pixmap);
   cairo_scale(cr, zoom, zoom);
   cairo_set_source_surface(cr, ssprite->surface, canvas_x, canvas_y);
   cairo_paint(cr);
-  gdk_window_end_draw_frame(pixmap, ctx);
+  cairo_destroy(cr);
 }
 
 /**************************************************************************
@@ -763,8 +737,6 @@ void draw_selection_rectangle(int canvas_x, int canvas_y, int w, int h)
   double dashes[2] = {4.0, 4.0};
   struct color *pcolor;
   cairo_t *cr;
-  GdkDrawingContext *ctx;
-  GdkWindow *wndw;
 
   if (w == 0 || h == 0) {
     return;
@@ -775,17 +747,22 @@ void draw_selection_rectangle(int canvas_x, int canvas_y, int w, int h)
     return;
   }
 
-  wndw = gtk_widget_get_window(map_canvas);
-  ctx = gdk_window_begin_draw_frame(wndw,
-                                    gdk_window_get_clip_region(wndw));
-  cr = gdk_drawing_context_get_cairo_context(ctx);
+  cr = gdk_cairo_create(gtk_widget_get_window(map_canvas));
   gdk_cairo_set_source_rgba(cr, &pcolor->color);
   cairo_set_line_width(cr, 2.0);
   cairo_set_dash(cr, dashes, 2, 0);
-  cairo_set_operator(cr, CAIRO_OPERATOR_DIFFERENCE);
+#ifdef FREECIV_MSWINDOWS
+  if (cairo_version() < CAIRO_VERSION_ENCODE(1, 12, 0)) {
+    /* Cairo has crashing CAIRO_OPERATOR_DIFFERENCE on win32 surface */
+    cairo_set_operator(cr, CAIRO_OPERATOR_XOR);
+  } else
+#endif /* FREECIV_MSWINDOWS */
+  {
+    cairo_set_operator(cr, CAIRO_OPERATOR_DIFFERENCE);
+  }
   cairo_rectangle(cr, canvas_x, canvas_y, w, h);
   cairo_stroke(cr);
-  gdk_window_end_draw_frame(wndw, ctx);
+  cairo_destroy(cr);
 }
 
 /**************************************************************************
