@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996-2004 - The Freeciv Team
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -179,8 +179,8 @@ void fc_client::create_main_page(void)
     strncpy(msgbuf, _("Qt client"), sizeof(msgbuf) - 1);
   }
 
-  painter.drawText(main_graphics.width()-fm.width(msgbuf)-10,
-                   main_graphics.height()-fm.descent(), msgbuf);
+  painter.drawText(main_graphics.width() - fm.horizontalAdvance(msgbuf) - 10,
+                   main_graphics.height() - fm.descent(), msgbuf);
   free_main_pic->setPixmap(main_graphics);
   pages_layout[PAGE_MAIN]->addWidget(free_main_pic,
                                      row++, 0, 1, 2, Qt::AlignCenter);
@@ -1131,7 +1131,7 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
   QVariant qvar;
   QString str_pixmap;
 
-  client_pages i = current_page();
+  client_pages cpage = current_page();
   const char *terr_name;
   const struct server *pserver = NULL;
   int ii = 0;
@@ -1144,7 +1144,7 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
     return;
   }
 
-  switch (i) {
+  switch (cpage) {
   case PAGE_NETWORK:
     index = indexes.at(0);
     connect_host_edit->setText(index.data().toString());
@@ -1324,17 +1324,20 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
 
         /* Create image */
         QImage img(nat_x, nat_y, QImage::Format_ARGB32_Premultiplied);
+
         img.fill(Qt::black);
         for (int a = 0 ; a < nat_x; a++) {
           for (int b = 0; b < nat_y; b++) {
             struct terrain *tr;
             struct rgbcolor *rgb;
+
             tr = char2terrain(str_pixmap.at(b * nat_x + a).toLatin1());
             if (tr != nullptr) {
               rgb = tr->rgb;
-              QColor col;
-              col.setRgb(rgb->r, rgb->g, rgb->b);
-              img.setPixel(a, b, col.rgb());
+              QColor color;
+
+              color.setRgb(rgb->r, rgb->g, rgb->b);
+              img.setPixel(a, b, color.rgb());
             }
           }
         }
@@ -1418,7 +1421,6 @@ void fc_client::update_scenarios_page(void)
       QTableWidgetItem *item;
       QString format;
       QString st;
-      QStringList sl;
       int fcver;
       int current_ver = MAJOR_VERSION *10000 + MINOR_VERSION *100;
 
