@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 ***********************************************************************/
 
 /**********************************************************************
-                          gui_stuff.h  -  description
+                          widget.h  -  description
                              -------------------
     begin                : June 30 2002
     copyright            : (C) 2002 by Rafał Bursig
@@ -50,9 +50,9 @@ enum widget_type {		/* allow 64 widgets type */
   WT_VSCROLLBAR = 24,		/* bugy */
   WT_HSCROLLBAR = 28,		/* bugy */
   WT_WINDOW	= 32,
-  WT_T_LABEL	= 36,		/* text label with theme backgroud */
+  WT_T_LABEL	= 36,		/* text label with theme background */
   WT_I_LABEL	= 40,		/* text label with icon */
-  WT_TI_LABEL	= 44,		/* text label with icon and theme backgroud.
+  WT_TI_LABEL	= 44,		/* text label with icon and theme background.
 				   NOTE: Not DEFINED- don't use
 				   ( can't be transp. ) */
   WT_CHECKBOX	= 48,		/* checkbox. */
@@ -205,37 +205,37 @@ void del_main_list(void);
 struct widget *find_next_widget_at_pos(struct widget *pStartWidget, int x, int y);
 struct widget *find_next_widget_for_key(struct widget *pStartWidget, SDL_Keysym key);
 
-struct widget *get_widget_pointer_form_ID(const struct widget *pGUI_List, Uint16 ID,
+struct widget *get_widget_pointer_from_id(const struct widget *pGUI_List, Uint16 ID,
                                           enum scan_direction direction);
 
-struct widget *get_widget_pointer_form_main_list(Uint16 ID);
+struct widget *get_widget_pointer_from_main_list(Uint16 ID);
 
 #define set_action(ID, action_callback)	\
-	get_widget_pointer_form_main_list(ID)->action = action_callback
+	get_widget_pointer_from_main_list(ID)->action = action_callback
 
 #define set_key(ID, keyb)	\
-	get_widget_pointer_form_main_list(ID)->key = keyb
+	get_widget_pointer_from_main_list(ID)->key = keyb
 
 #define set_mod(ID, mod)	\
-	get_widget_pointer_form_main_list(ID)->mod = mod
+	get_widget_pointer_from_main_list(ID)->mod = mod
 
 #define enable(ID)						\
 do {								\
-  struct widget *____pGUI = get_widget_pointer_form_main_list(ID);	\
+  struct widget *____pGUI = get_widget_pointer_from_main_list(ID);	\
   set_wstate(____pGUI, FC_WS_NORMAL);				\
 } while (FALSE)
 
 #define disable(ID)						\
 do {								\
-  struct widget *____pGUI = get_widget_pointer_form_main_list(ID);	\
+  struct widget *____pGUI = get_widget_pointer_from_main_list(ID);	\
   set_wstate(____pGUI , FC_WS_DISABLED);				\
 } while (FALSE)
 
 #define show(ID)	\
-  clear_wflag( get_widget_pointer_form_main_list(ID), WF_HIDDEN)
+  clear_wflag( get_widget_pointer_from_main_list(ID), WF_HIDDEN)
 
 #define hide(ID)	\
-  set_wflag(get_widget_pointer_form_main_list(ID), WF_HIDDEN)
+  set_wflag(get_widget_pointer_from_main_list(ID), WF_HIDDEN)
 
 void widget_selected_action(struct widget *pWidget);
 Uint16 widget_pressed_action(struct widget *pWidget);
@@ -375,14 +375,14 @@ do {						\
 
 #define del_ID_from_gui_list(ID)				\
 do {								\
-  struct widget *___pTmp = get_widget_pointer_form_main_list(ID);	\
+  struct widget *___pTmp = get_widget_pointer_from_main_list(ID);	\
   del_widget_pointer_from_gui_list(___pTmp);			\
   FREEWIDGET(___pTmp);						\
 } while (FALSE)
 
 #define move_ID_to_front_of_gui_list(ID)	\
 	move_widget_to_front_of_gui_list(       \
-          get_widget_pointer_form_main_list(ID))
+          get_widget_pointer_from_main_list(ID))
 
 #define del_group(pBeginGroupWidgetList, pEndGroupWidgetList)		\
 do {									\
@@ -410,7 +410,7 @@ bool del_widget_from_vertical_scroll_widget_list(struct ADVANCED_DLG *pDlg,
                                                  struct widget *pWidget);
 
 /* misc */
-SDL_Surface *create_bcgnd_surf(SDL_Surface *ptheme, Uint8 state,
+SDL_Surface *create_bcgnd_surf(SDL_Surface *ptheme, enum widget_state state,
                                Uint16 width, Uint16 height);
 void draw_frame(SDL_Surface *pDest, Sint16 start_x, Sint16 start_y,
                 Uint16 w, Uint16 h);
