@@ -21,6 +21,7 @@
 
 /* common */
 #include "game.h"
+#include "map.h"
 #include "tile.h"
 #include "unit.h"
 
@@ -47,12 +48,14 @@ int tile_border_source_radius_sq(struct tile *ptile)
     radius_sq += MIN(city_size_get(pcity), CITY_MAP_MAX_RADIUS_SQ)
                  * game.info.border_size_effect;
   } else {
-    base_type_iterate(pbase) {
-      if (tile_has_base(ptile, pbase) && territory_claiming_base(pbase)) {
+    extra_type_by_cause_iterate(EC_BASE, pextra) {
+      struct base_type *pbase = extra_base_get(pextra);
+
+      if (tile_has_extra(ptile, pextra) && territory_claiming_base(pbase)) {
         radius_sq = pbase->border_sq;
         break;
       }
-    } base_type_iterate_end;
+    } extra_type_by_cause_iterate_end;
   }
 
   return radius_sq;
@@ -75,12 +78,14 @@ int tile_border_source_strength(struct tile *ptile)
   if (pcity) {
     strength = city_size_get(pcity) + 2;
   } else {
-    base_type_iterate(pbase) {
-      if (tile_has_base(ptile, pbase) && territory_claiming_base(pbase)) {
+    extra_type_by_cause_iterate(EC_BASE, pextra) {
+      struct base_type *pbase = extra_base_get(pextra);
+
+      if (tile_has_extra(ptile, pextra) && territory_claiming_base(pbase)) {
         strength = 1;
         break;
       }
-    } base_type_iterate_end;
+    } extra_type_by_cause_iterate_end;
   }
 
   return strength;
@@ -110,12 +115,14 @@ bool is_border_source(struct tile *ptile)
     return TRUE;
   }
 
-  if (tile_owner(ptile) != NULL) {
-    base_type_iterate(pbase) {
-      if (tile_has_base(ptile, pbase) && territory_claiming_base(pbase)) {
+  if (extra_owner(ptile) != NULL) {
+    extra_type_by_cause_iterate(EC_BASE, pextra) {
+      struct base_type *pbase = extra_base_get(pextra);
+
+      if (tile_has_extra(ptile, pextra) && territory_claiming_base(pbase)) {
         return TRUE;
       }
-    } base_type_iterate_end;
+    } extra_type_by_cause_iterate_end;
   }
 
   return FALSE;
